/*  GFC-UI: Gtk+ Foundation Classes (User Interface Library)
 *  Copyright (C) 2002-2004 The GFC Development Team.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/// @file gfc/gfcui.hh
/// @brief The main GFC-UI header file.
///
/// This header file includes all the GFC-UI header files and the compile-time
/// GFC-UI version numbers. You can safely include this header file only, with
/// minimal extra overhead, because each header file uses include guards to prevent
/// multiple inclusions.

/// @defgroup main_group The Main Namespace
/// @namespace GFC::Main
/// @ingroup gfc_group
/// @brief The initialization, main event loop and event namespace.
///
/// Provides a set of methods and signals for handling program
/// initialization and custom event loop processing.

/// @defgroup atk_group The Atk Namespace
/// @namespace GFC::Atk
/// @ingroup gfc_group
/// @brief The C++ framework for the ATK Accessibility Toolkit.
///
/// Provides a set of generic interfaces allowing accessibility
/// technologies to interact with a graphical user interface.
/// For example, a screen reader uses ATK to discover the text
/// in an interface and read it to blind users. GTK+ widgets have
/// built-in support for accessibility using the ATK framework.

/// @defgroup gdk_group The Gdk Namespace
/// @namespace GFC::Gdk
/// @ingroup gfc_group
/// @brief The C++ framework for the GTK+ Drawing Kit and the GdkPixbuf library.
///
/// Provides an API that can be used to add two-dimensional graphics
/// to your program. GDK itself is the abstraction layer that allows
/// GTK+ to support multiple windowing systems. GDK provides drawing
/// and window system facilities on X11, Windows, and the Linux 
/// framebuffer device.

/// @defgroup gtk_group The Gtk Namespace
/// @namespace GFC::Gtk
/// @ingroup gfc_group
/// @brief The C++ framework for the GTK GUI library.
///
/// Provides a set of graphical objects called widgets which serve as
/// the GUI component, such as Gtk::Button and Gtk::Textview.

/// @defgroup pango_group The Pango Namespace
/// @namespace GFC::Pango
/// @ingroup gfc_group
/// @brief The C++ framework for the Pango text handling library.
///
/// Pango is a library for internationalized text handling. It centers
/// around the Pango::Layout object, representing a paragraph of text.
/// Pango provides the engine for Gtk::TextView, Gtk::Label, Gtk::Entry
/// and other widgets that display text.

#ifndef GFC_UI_H
#define GFC_UI_H

/// Compile time major version macro.
#define GFC_UI_MAJOR_VERSION (2)

/// Compile time minor version macro.
#define GFC_UI_MINOR_VERSION (3)

/// Compile time micro version macro.
#define GFC_UI_MICRO_VERSION (1)

#include <gfc/atk/atk.hh>
#include <gfc/gdk/gdk.hh>
#include <gfc/gdk-pixbuf/gdk-pixbuf.hh>
#include <gfc/gtk/gtk.hh>
#include <gfc/pango/pango.hh>

/// @name Library Version
/// @{

extern const unsigned int gfc_ui_major_version;
///< Major version  number.

extern const unsigned int gfc_ui_minor_version;
///< Minor version  number.

extern const unsigned int gfc_ui_micro_version;
///< Micro version  number.

bool gfc_ui_check_version(int major, int minor, int micro);
///< Check whether an GFC-UI version equal to or greater than major.minor.micro is present.

/// @}

#endif // GFC_UI_H

