/*  GFC-UI: GTK+ Foundation Classes (User Interface Library)
 *  Copyright (C) 2004 The GFC Development Team.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
/// @file gfc/gtk/labelsignals.hh
/// @brief Gtk::Label virtual signal handlers.
///
/// Provides Gtk::LabelSignals, an abstract base class that implements
/// the overridable virtual signal handlers for Gtk::Label objects.

#ifndef GFC_GTK_LABEL_SIGNALS_HH
#define GFC_GTK_LABEL_SIGNALS_HH

#ifndef GFC_GTK_WIDGET_SIGNALS_HH
#include <gfc/gtk/widgetsignals.hh>
#endif

namespace GFC {

namespace Gtk {

/// @class LabelSignals labelsignals.hh gfc/gtk/labelsignals.hh
/// @brief Abstract base class that implements the virtual signal handlers for Gtk::Label.

class LabelSignals : public WidgetSignals
{
protected:
/// @name Constructors
/// @{

	LabelSignals(Label *label);
	///< Construct an empty LabelSignals object.

	virtual ~LabelSignals() = 0;
	///< Destructor.

/// @}

public:
/// @name Signal Handlers
/// @{

	virtual void on_populate_popup(Menu& menu);
	///< Called just before the popup menu is displayed in response the a right-click on a selectable label.
	///< @param menu The popup menu.

/// @}
};

} // namespace Gtk

} // namespace GFC

#endif // GFC_GTK_LABEL_SIGNALS_HH

