/*  GFC-UI: GTK+ Foundation Classes (User Interface Library)
 *  Copyright (C) 2004 The GFC Development Team.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
/// @file gfc/gtk/layoutsignals.hh
/// @brief Gtk::Layout virtual signal handlers.
///
/// Provides Gtk::LayoutSignals, an abstract base class that implements
/// the overridable virtual signal handlers for Gtk::Layout objects.

#ifndef GFC_GTK_LAYOUT_SIGNALS_HH
#define GFC_GTK_LAYOUT_SIGNALS_HH

#ifndef GFC_GTK_CONTAINER_SIGNALS_HH
#include <gfc/gtk/containersignals.hh>
#endif

namespace GFC {

namespace Gtk {

/// @class LayoutSignals layoutsignals.hh gfc/gtk/layoutsignals.hh
/// @brief Abstract base class that implements the virtual signal handlers for Gtk::Layout.

class LayoutSignals : public ContainerSignals
{
protected:
/// @name Constructors
/// @{

	LayoutSignals(Layout *layout);
	///< Construct a new LayoutSignals object.
	///< @param layout A Layout object inheriting the LayoutSignals implementation.

	virtual ~LayoutSignals() = 0;
	///< Destructor.

/// @}

public:
/// @name Signal Handlers
/// @{

	virtual void on_set_scroll_adjustments(Adjustment *hadjustment, Adjustment *vadjustment);
	///< Called when a layout is added to a scrolling aware parent.
	///< @param hadjustment The horizontal adjustment.
	///< @param vadjustment The vertical adjustment.

/// @}
};

} // namespace Gtk

} // namespace GFC

#endif // GFC_GTK_LAYOUT_HH

